/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/
package org.apache.james.mailbox.store.quota;

import java.util.HashMap;
import java.util.Map;

import org.apache.james.mailbox.MailboxException;
import org.apache.james.mailbox.MailboxSession;
import org.apache.james.mailbox.quota.Quota;
import org.apache.james.mailbox.store.StoreMailboxManager;

/**
 * Allows to set a per Users quota
 * 
 *
 */
public class PerUserQuotaManager<Id> extends ListeningQuotaManager{

    public PerUserQuotaManager(StoreMailboxManager<Id> manager) throws MailboxException {
        super(manager);
    }

    private long maxMessage = Quota.UNLIMITED;
    private long maxStorage = Quota.UNLIMITED;
    
    private Map<String, Long> userMaxStorage = new HashMap<String, Long>();
    private Map<String, Long> userMaxMessage = new HashMap<String, Long>();

    public void setUserMaxStorage(Map<String, Long> userMaxStorage) {
        this.userMaxStorage = userMaxStorage;
    }
    
    public void setUserMaxMessage(Map<String, Long> userMaxMessage) {
        this.userMaxMessage = userMaxMessage;
    }
    
    public void setDefaultMaxStorage(long maxStorage) {
        this.maxStorage = maxStorage;
    }
    
    public void setDefaultMaxMessage(long maxMessage) {
        this.maxMessage = maxMessage;
    }
    
    @Override
    protected long getMaxStorage(MailboxSession session) throws MailboxException {
        Long max = userMaxStorage.get(session.getUser().getUserName());
        if (max == null) {
            max = maxStorage;
        }
        return max;
    }

    @Override
    protected long getMaxMessage(MailboxSession session) throws MailboxException {
        Long max = userMaxMessage.get(session.getUser().getUserName());
        if (max == null) {
            max = maxMessage;
        }
        return max;
    }

}
